@@ -190,7 +190,12 @@ static void drm_fb_helper_sys_imageblit(struct fb_info *info, const struct fb_im
 static struct fb_ops vboxfb_ops = {
 	.owner = THIS_MODULE,
 	.fb_check_var = drm_fb_helper_check_var,
+#if RTLNX_VER_MAX(6,15,0) && !RTLNX_RHEL_RANGE(9,7, 9,99)
+	/* We seem do not follow all the procedure of instantiating DRM Client.
+	 * Having this callback set will trigger panic on module load. Comment
+	 * it out for now. */
 	.fb_set_par = drm_fb_helper_set_par,
+#endif
 #if RTLNX_VER_MIN(6,5,0) || RTLNX_RHEL_RANGE(9,4, 9,99) || RTLNX_SUSE_MAJ_PREREQ(15, 6)
 	.fb_read    = fb_sys_read,
 	.fb_write   = fb_sys_write,
@@ -407,7 +412,7 @@ int vboxfb_create(struct drm_fb_helper *helper,
 	return 0;
 }
 
-#if RTLNX_VER_MAX(6,15,0)
+#if RTLNX_VER_MAX(6,15,0) && !RTLNX_RHEL_RANGE(9,7, 9,99)
 static struct drm_fb_helper_funcs vbox_fb_helper_funcs = {
 	.fb_probe = vboxfb_create,
 };
@@ -480,7 +485,7 @@ int vbox_fbdev_init(struct drm_device *dev)
 	vbox->fbdev = fbdev;
 	spin_lock_init(&fbdev->dirty_lock);
 
-#if RTLNX_VER_MIN(6,15,0)
+#if RTLNX_VER_MIN(6,15,0) || RTLNX_RHEL_RANGE(9,7, 9,99)
 	drm_fb_helper_prepare(dev, &fbdev->helper, 32, NULL);
 #elif RTLNX_VER_MIN(6,3,0) || RTLNX_RHEL_RANGE(8,9, 8,99) || RTLNX_RHEL_RANGE(9,3, 9,99)
 	drm_fb_helper_prepare(dev, &fbdev->helper, 32, &vbox_fb_helper_funcs);
